@@ -28,7 +28,7 @@ def get_page(request, items, count_per_page):
 
 
 @login_required
-def file_list(request, template='s3filemanage/index.html', extra_context=None):
+def file_list(request, template='s3filesmanager/index.html', extra_context=None):
     paginator = get_page(request, S3File.objects.filter(owner=request.user).order_by('-created'), 10)
     context = {
         'paginator': paginator,
